@@ -161,7 +161,7 @@ import { Port, Peer, Vpc, SubnetType } from 'aws-cdk-lib/aws-ec2';
 import { ManagedPolicy } from 'aws-cdk-lib/aws-iam';
 
 const newvpc = new Vpc(stack, 'VPC', {
-  cidr: '10.1.0.0/16',
+  ipAddresses: IpAddresses.cidr('10.0.0.0/16'),
   maxAzs: 2,
   subnetConfiguration: [
     {
@@ -911,7 +911,7 @@ class GitlabContainerRunnerProps:
         Example::
 
             const newvpc = new Vpc(stack, 'NEWVPC', {
-              cidr: '10.1.0.0/16',
+              ipAddresses: IpAddresses.cidr('10.0.0.0/16'),
               maxAzs: 2,
               subnetConfiguration: [{
                 cidrMask: 26,
@@ -1102,7 +1102,7 @@ class GitlabRunnerAutoscaling(
         :param spot_instance: (experimental) Run worker nodes as EC2 Spot. Default: - false
         :param tags: (experimental) tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         :param vpc: (experimental) VPC for the Gitlab Runner . Default: - A new VPC will be created.
-        :param vpc_subnet: (experimental) VPC subnet. Default: - private subnet
+        :param vpc_subnet: (experimental) VPC subnet. Default: - SubnetType.PRIVATE subnet
 
         :stability: experimental
         '''
@@ -1165,7 +1165,7 @@ class GitlabRunnerAutoscaling(
         :param spot_instance: (experimental) Run worker nodes as EC2 Spot. Default: - false
         :param tags: (experimental) tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         :param vpc: (experimental) VPC for the Gitlab Runner . Default: - A new VPC will be created.
-        :param vpc_subnet: (experimental) VPC subnet. Default: - private subnet
+        :param vpc_subnet: (experimental) VPC subnet. Default: - SubnetType.PRIVATE subnet
 
         :return: Array.
 
@@ -1294,7 +1294,7 @@ class GitlabRunnerAutoscalingProps:
         :param spot_instance: (experimental) Run worker nodes as EC2 Spot. Default: - false
         :param tags: (experimental) tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         :param vpc: (experimental) VPC for the Gitlab Runner . Default: - A new VPC will be created.
-        :param vpc_subnet: (experimental) VPC subnet. Default: - private subnet
+        :param vpc_subnet: (experimental) VPC subnet. Default: - SubnetType.PRIVATE subnet
 
         :stability: experimental
         '''
@@ -1564,7 +1564,7 @@ class GitlabRunnerAutoscalingProps:
         Example::
 
             const newVpc = new Vpc(stack, 'NewVPC', {
-              cidr: '10.1.0.0/16',
+              ipAddresses: IpAddresses.cidr('10.0.0.0/16'),
               maxAzs: 2,
               subnetConfiguration: [{
                 cidrMask: 26,
@@ -1583,7 +1583,7 @@ class GitlabRunnerAutoscalingProps:
     def vpc_subnet(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.SubnetSelection]:
         '''(experimental) VPC subnet.
 
-        :default: - private subnet
+        :default: - SubnetType.PRIVATE subnet
 
         :stability: experimental
 
